summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcylinderedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcylinderedit.h')
-rw-r--r--kpovmodeler/pmcylinderedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmcylinderedit.h b/kpovmodeler/pmcylinderedit.h
index 9f2c0993..9b25ec2a 100644
--- a/kpovmodeler/pmcylinderedit.h
+++ b/kpovmodeler/pmcylinderedit.h
@@ -34,12 +34,13 @@ class TQCheckBox;
class PMCylinderEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMCylinderEdit with parent and name
*/
- PMCylinderEdit( TQWidget* parent, const char* name = 0 );
+ PMCylinderEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -34,12 +34,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMCylinderEdit with parent and name
+ * Creates a PMCylinderEdit with tqparent and name
*/